﻿using Connected.Models;
using Microsoft.AspNetCore.Components;
using Microsoft.AspNetCore.Components.Web;
using System;

namespace Connected.Components;
public partial class SimpleSelect<ValueType> : InputBase
{
	[Parameter]
	public ValueType Value { get; set; }

	[Parameter]
	public IEnumerable<ValueType> Items { get; set; }

	public IEnumerable<ValueType> OriginalItems { get; set; }

	[Parameter]
	public bool EnableSearch { get; set; } = true;

	private string _searchText { get; set; } = string.Empty;
	public string SearchText
	{
		get
		{
			return _searchText;
		}
		set
		{
			_searchText = value;
			FilterItems();
		}
	}

	private async Task FilterItems()
	{
		if (string.IsNullOrEmpty(_searchText))
		{
			Items = OriginalItems;
		}
		else
		{
			Items = Items.Where(item => item.ToString().ToLower().Contains(_searchText.ToLower()));
		}
		StateHasChanged();
	}


	[Parameter]
	public EventCallback<ValueType> ValueChanged { get; set; }

	private async Task ChangeValueAsync(ChangeEventArgs args)
	{
		await ValueChanged.InvokeAsync((ValueType)Convert.ChangeType(args.Value, typeof(ValueType)));
	}

	protected override async Task OnParametersSetAsync()
	{
		if (base.InputAttributes is null) base.InputAttributes = new();
		if (base.Required)
		{
			if (base.InputAttributes.ContainsKey("required")) base.InputAttributes.Add("required", true);
		}
		OriginalItems = Items;
		await base.OnInitializedAsync();
	}
}